Package: eyetrackingR
Type: Package
Version: 0.2.2
Title: Eye-Tracking Data Analysis
Authors@R: c(
    person("Samuel", "Forbes", email = "samuel.h.forbes@gmail.com", role = c("aut", "cre")),
	person("Jacob", "Dink", email = "jacobwdink@gmail.com", role = c("aut")),
	person("Brock", "Ferguson", email = "brock.ferguson@gmail.com", role = c("aut"))
	)
Description: Addresses tasks along the pipeline from raw
    data to analysis and visualization for eye-tracking data. Offers several
    popular types of analyses, including linear and growth curve time analyses,
    onset-contingent reaction time analyses, as well as several non-parametric
    bootstrapping approaches. For references to the approach see Mirman, 
    Dixon & Magnuson (2008) <doi:10.1016/j.jml.2007.11.006>, and
    Barr (2008) <doi:10.1016/j.jml.2007.09.002>.
URL: https://samforbes.me/eyetrackingR/
BugReports: https://github.com/samhforbes/eyetrackingR/issues
Date: 2025-07-02
Depends: R (>= 3.2.0), dplyr (>= 0.7.4)
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
Imports: broom (>= 0.3.7), broom.mixed, ggplot2 (>= 2.0), lazyeval (>=
        0.1.10), rlang, zoo (>= 1.7-12), tidyr (>= 0.3.1), purrr (>=
        0.2.4)
Suggests: pbapply, knitr, lme4 (>= 1.1-10), glmmTMB, MASS, Matrix,
        testthat, rmarkdown, doMC, foreach
VignetteBuilder: knitr
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-06-17 08:55:50 UTC; xbxr94
Author: Samuel Forbes [aut, cre],
  Jacob Dink [aut],
  Brock Ferguson [aut]
Maintainer: Samuel Forbes <samuel.h.forbes@gmail.com>
Repository: CRAN
Date/Publication: 2025-06-18 09:30:02 UTC
Built: R 4.6.0; ; 2026-04-25 13:41:20 UTC; unix
