# Generated by roxygen2: do not edit by hand

S3method("[",eyetrackingR_df)
S3method(analyze_boot_splines,boot_splines_data)
S3method(analyze_time_bins,time_sequence_data)
S3method(analyze_time_clusters,time_cluster_data)
S3method(arrange,eyetrackingR_df)
S3method(arrange_,eyetrackingR_df)
S3method(filter,eyetrackingR_df)
S3method(filter_,eyetrackingR_df)
S3method(get_time_clusters,cluster_analysis)
S3method(get_time_clusters,time_cluster_data)
S3method(group_by,eyetrackingR_df)
S3method(group_by_,eyetrackingR_df)
S3method(inner_join,eyetrackingR_df)
S3method(left_join,eyetrackingR_df)
S3method(make_boot_splines_data,time_sequence_data)
S3method(make_switch_data,onset_data)
S3method(make_time_cluster_data,time_sequence_data)
S3method(mutate,eyetrackingR_df)
S3method(mutate_,eyetrackingR_df)
S3method(plot,bin_analysis)
S3method(plot,boot_splines_analysis)
S3method(plot,boot_splines_data)
S3method(plot,cluster_analysis)
S3method(plot,eyetrackingR_data_summary)
S3method(plot,onset_data)
S3method(plot,switch_data)
S3method(plot,time_cluster_data)
S3method(plot,time_sequence_data)
S3method(plot,time_window_data)
S3method(print,cluster_analysis)
S3method(reclass,eyetrackingR_df)
S3method(summary,bin_analysis)
S3method(summary,boot_splines_analysis)
S3method(summary,cluster_analysis)
S3method(summary,time_cluster_data)
export(add_aoi)
export(analyze_boot_splines)
export(analyze_time_bins)
export(analyze_time_clusters)
export(clean_by_trackloss)
export(describe_data)
export(get_time_clusters)
export(make_boot_splines_data)
export(make_eyetrackingr_data)
export(make_onset_data)
export(make_switch_data)
export(make_time_cluster_data)
export(make_time_sequence_data)
export(make_time_window_data)
export(reclass)
export(simulate_eyetrackingr_data)
export(subset_by_window)
export(trackloss_analysis)
import(dplyr)
import(ggplot2)
importFrom(graphics,plot)
importFrom(lazyeval,interp)
importFrom(purrr,map)
importFrom(purrr,map_lgl)
importFrom(stats,as.formula)
importFrom(stats,df.residual)
importFrom(stats,formula)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,p.adjust)
importFrom(stats,plogis)
importFrom(stats,poly)
importFrom(stats,predict)
importFrom(stats,qgamma)
importFrom(stats,qlogis)
importFrom(stats,qnorm)
importFrom(stats,qsignrank)
importFrom(stats,qt)
importFrom(stats,quantile)
importFrom(stats,rbinom)
importFrom(stats,rexp)
importFrom(stats,rgamma)
importFrom(stats,rnorm)
importFrom(stats,rpois)
importFrom(stats,sd)
importFrom(tidyr,gather)
importFrom(tidyr,spread)
